@@ -1,18 +1,17 @@
 import os
-from tkinter import Tk, Button, Listbox, Entry, Label
+from tkinter import Tk, Button, Entry, Label
 from tkinter.ttk import Treeview, Notebook, Frame, Scrollbar
 from tkinter import RIGHT, LEFT, TOP, BOTTOM, END
 from tkinter import W
-from tkinter import MULTIPLE
 from tkinter import filedialog, messagebox
 from math import log
-from typing import List, Tuple
 
-from .catalogue import Catalogue, DirItem
-from .tree import Tree, DataTree
+from .catalogue import Catalogue
+from .container import DirItem
+from .tree import Tree
 from .logger import logger
 
-item_colors = {"file": "#FFF0D9", "dir": "#D7F4F3"}  # Papaya Whip, Water
+item_colors = {"file": "#fcfade", "dir": "#D7F4F3"}  # Cornsilk, Water
 
 
 def humanReadableSize(size: int) -> str:
@@ -29,7 +28,7 @@ def humanReadableSize(size: int) -> str:
     """
     size_suffixes = ["K", "M", "G", "T"]
 
-    if size == 0:
+    if size <= 0:
         return "0"
 
     logger.debug(f"Calculating h.r. size for bytes: {size}.")
@@ -68,37 +67,17 @@ class GUITree(Tree, Treeview):
         self.tag_configure("file", background=item_colors["file"])
         self.tag_configure("dir", background=item_colors["dir"])
 
-    def deleteByIDs(self, iids: Tuple[str], data_tree: DataTree):
-        logger.debug(f"Deleting iids {iids}.")
-        for iid in iids:
-            item = data_tree.findByID(iid)
-            if item:
-                size = item.size
-            else:
-                continue
+    def deleteSubtree(self, item):
+        self.delete(item.iid)
 
-            parent = self.parent(iid)
-            if parent:
-                update = -size
-                self.updateAncestorsSize(iid, update, data_tree)
-
-            self.deleteSubtree(iid)
-
-    def deleteSubtree(self, iid: str):
-        self.delete(iid)
-
-    def updateAncestorsSize(self, item_iid: str, update: int, data_tree: DataTree):
-        parent = self.parent(item_iid)
-        while parent:
-            name = self.item(parent)["values"][0]
-            item = data_tree.findByID(parent)
-            if item:
-                size = item.size
-            else:
-                continue
-            new_hr_size = humanReadableSize(size + update)
-            self.item(parent, values=(name, new_hr_size))
-            parent = self.parent(parent)
+    def updateAncestors(self, item):
+        parent_iid = self.parent(item.iid)
+        parent_item = item.parent
+        while parent_iid:
+            new_hr_size = humanReadableSize(parent_item.size)
+            self.item(parent_iid, values=(new_hr_size,))
+            parent_iid = self.parent(parent_iid)
+            parent_item = item.parent
 
     def insertDirItem(self, dir_item: DirItem):
         dir_iid = dir_item.iid
@@ -157,14 +136,21 @@ class GUI:
 
         """ ### create right side ### """
 
-        self.frame_right = Frame(self.root, borderwidth=10, height=360, width=200)
-        self.frame_right.pack(side=RIGHT, expand=1, fill="both")
+        right_frame_w = w // 4
+
+        self.frame_right = Frame(self.root, borderwidth=10, width=right_frame_w)
+        self.frame_right.pack(side=RIGHT, fill="both")
         self.frame_right.pack_propagate(0)
 
+        # self.frame_counter = Frame(self.frame_right, borderwidth=30, height=200)
+        # self.frame_counter.pack(side=BOTTOM)
+        # self.lbl_counter = Label(self.frame_counter, text="Total count")
+        # self.lbl_counter.pack(side=TOP)
+
         self.lbl_choose_info = Label(
             self.frame_right, text="Start folder:", width=50, anchor=W
         )
-        self.lbl_choose_info.pack(side=TOP)
+        self.lbl_choose_info.pack(side=TOP, pady=(30, 0))
 
         """ Folder entry """
 
@@ -179,7 +165,7 @@ class GUI:
             width=50,
             command=self.btnChooseFolder,
         )
-        self.button_choose_folder.pack(side=TOP, pady=10)
+        self.button_choose_folder.pack(side=TOP, pady=15)
 
         """ Button walk and list directory in folder entry """
         self.button_list = Button(
@@ -187,6 +173,40 @@ class GUI:
         )
         self.button_list.pack(side=TOP)
 
+        """ Total count info """
+
+        frame_counter = Frame(
+            self.frame_right, borderwidth=2, height=200, relief="groove"
+        )
+        frame_counter.pack(side=TOP, pady=30)
+
+        self.lbl_count_title = Label(frame_counter, text="Total numbers")
+        self.lbl_count_title.pack(side=TOP, pady=(10, 20))
+
+        padding_2_frame = 10
+
+        frame_usedspace = Frame(frame_counter)
+        frame_usedspace.pack(side=BOTTOM, anchor=W, padx=padding_2_frame)
+        frame_fcount = Frame(frame_counter)
+        frame_fcount.pack(side=BOTTOM, anchor=W, padx=padding_2_frame)
+        frame_dcount = Frame(frame_counter)
+        frame_dcount.pack(side=BOTTOM, anchor=W, padx=padding_2_frame)
+
+        self.lbl_usedspace = Label(frame_usedspace, text="0", font="Arial 9 bold")
+        self.lbl_usedspace.pack(side=RIGHT, pady=5, padx=(5, 5))
+        txt_dirs = Label(frame_usedspace, text="Used space:", width=10)
+        txt_dirs.pack(side=LEFT, pady=5)
+
+        self.lbl_dir_counter = Label(frame_dcount, text="0", font="Arial 9 bold")
+        self.lbl_dir_counter.pack(side=RIGHT, pady=5, padx=(5, 5))
+        txt_dirs = Label(frame_dcount, text="Folders:", width=10)
+        txt_dirs.pack(side=LEFT, pady=5)
+
+        self.lbl_file_counter = Label(frame_fcount, text="0", font="Arial 9 bold")
+        self.lbl_file_counter.pack(side=RIGHT, pady=5, padx=(5, 5))
+        txt_files = Label(frame_fcount, text="Files:", width=10)
+        txt_files.pack(side=LEFT, pady=5)
+
         """ button delete selection """
 
         self.button_delete_selected = Button(
@@ -195,7 +215,7 @@ class GUI:
             width=50,
             command=self.btnDeleteSelected,
         )
-        self.button_delete_selected.pack(side=TOP, pady=50)
+        self.button_delete_selected.pack(side=TOP, pady=20)
 
         """ quit button """
 
@@ -206,7 +226,11 @@ class GUI:
 
         """ ### create left side ### """
 
-        self.frame_left = Frame(self.root, borderwidth=10, height=360, width=350)
+        left_frame_w = w - right_frame_w
+
+        self.frame_left = Frame(
+            self.root, borderwidth=10, height=360, width=left_frame_w
+        )
         self.frame_left.pack(side=LEFT, expand=1, fill="both")
         self.frame_left.pack_propagate(0)
 
@@ -217,7 +241,7 @@ class GUI:
         tab_dirs = Frame(self.tabs)
         tab_tree = Frame(self.tabs)
         self.tabs.add(tab_files, text="Files")
-        self.tabs.add(tab_dirs, text="Directories")
+        self.tabs.add(tab_dirs, text="Folders")
         self.tabs.add(tab_tree, text="Tree View")
         self.tabs.pack(expand=1, fill="both")
 
@@ -350,6 +374,10 @@ class GUI:
             self.delDirs()
             self.listDirs()
 
+            self._setFileCountTxt()
+            self._setDirCountTxt()
+            self._setUsedSpace()
+
     def btnDeleteSelected(self):
         tab = self.tabs.tab(self.tabs.select(), "text")
 
@@ -357,7 +385,7 @@ class GUI:
             selection = self.tv_files.selection()
             for iid in selection:
                 self.tv_files.delete(iid)
-        elif tab == "Directories":
+        elif tab == "Folders":
             selection = self.tv_dirs.selection()
             for iid in selection:
                 self.tv_dirs.delete(iid)
@@ -366,15 +394,7 @@ class GUI:
 
         logger.info(f"Deleting selection from tab {tab}.")
 
-        self.guitree.deleteByIDs(selection, self.catalogue.tree)
-
-        # in case an item has been deleted on disk by the user / os
-        try:
-            self.catalogue.deleteByIDs(selection)
-        except FileNotFoundError as fne:
-            logger.error(
-                f"Cannot delete item since it does not seem to exist anymore: {fne}"
-            )
+        self.catalogue.deleteByIDs(selection)
 
         # completely deleting an resinserting is for simplicity
         # right now and will be changed
@@ -383,6 +403,10 @@ class GUI:
         self.delDirs()
         self.listDirs()
 
+        self._setFileCountTxt()
+        self._setDirCountTxt()
+        self._setUsedSpace()
+
     def delFiles(self):
         items = self.tv_files.get_children()
         for iid in items:
@@ -412,3 +436,13 @@ class GUI:
             self.tv_dirs.insert(
                 "", END, iid=iid, values=(name, size, parent), tags=["dir"]
             )
+
+    def _setFileCountTxt(self):
+        self.lbl_file_counter.config(text=str(self.catalogue.num_files))
+
+    def _setDirCountTxt(self):
+        self.lbl_dir_counter.config(text=str(self.catalogue.num_dirs))
+
+    def _setUsedSpace(self):
+        hr_total_size = humanReadableSize(self.catalogue.total_space)
+        self.lbl_usedspace.config(text=hr_total_size)
